Installation
============
The most recent release can be installed from
`PyPI <https://pypi.org/project/torch_max_mem>`_ with:

.. code-block:: shell

    $ pip install torch_max_mem

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    $ pip install git+https://github.com/mberr/torch-max-mem.git

To install in development mode, use the following:

.. code-block:: shell

    $ git clone git+https://github.com/mberr/torch-max-mem.git
    $ cd torch-max-mem
    $ pip install -e .
